@@ -1,4 +1,4 @@
-# Copyright 2009-2014 Ram Rachum.
+# Copyright 2009-2015 Ram Rachum.
 # This program is distributed under the MIT license.
 
 '''
@@ -8,14 +8,11 @@ See its documentation for more details.
 '''
 # todo: examine thread-safety
 
-import functools
 import datetime as datetime_module
 
-from python_toolbox import misc_tools
 from python_toolbox import binary_search
 from python_toolbox import decorator_tools
 from python_toolbox.sleek_reffing import SleekCallArgs
-from python_toolbox.nifty_collections import OrderedDict
 
 infinity = float('inf')
 
@@ -70,6 +67,10 @@ def cache(max_size=infinity, time_to_keep=None):
     # have to go through so much shit. update: probably it will help only for
     # completely argumentless function. so do one for those.
     
+    from python_toolbox.nifty_collections import OrderedDict
+    from python_toolbox import misc_tools
+    
+    
     if time_to_keep is not None:
         if max_size != infinity:
             raise NotImplementedError
@@ -101,9 +102,9 @@ def cache(max_size=infinity, time_to_keep=None):
                 def remove_expired_entries():
                     almost_cutting_point = \
                                           binary_search.binary_search_by_index(
-                        cached._cache.keys(),
-                        sorting_key_function,
+                        list(cached._cache.keys()),
                         _get_now(), 
+                        sorting_key_function,
                         rounding=binary_search.LOW
                     )
                     if almost_cutting_point is not None:
