@@ -1,4 +1,4 @@
-# Copyright 2009-2014 Ram Rachum.
+# Copyright 2009-2015 Ram Rachum.
 # This program is distributed under the MIT license.
 
 '''
@@ -104,7 +104,7 @@ class ContextManager(DecoratingContextManager):
                 raise RuntimeError(
                     "The generator didn't stop after the yield; possibly you "
                     "have more than one `yield` in the generator function? "
-                    "The generator function must yield exactly one time.")
+                    "The generator function must `yield` exactly one time.")
         else:
             if exc_value is None:
                 # Need to force instantiation so we can reliably
@@ -131,6 +131,6 @@ class ContextManager(DecoratingContextManager):
                 raise RuntimeError(
                     "The generator didn't stop after calling its `.throw()`; "
                     "Possibly you have more than one `yield` in the generator "
-                    "function? The generator function must yield exactly one "
+                    "function? The generator function must `yield` exactly one "
                     "time."
                 )
\ No newline at end of file
