@@ -1,4 +1,4 @@
-# Copyright 2009-2014 Ram Rachum.
+# Copyright 2009-2015 Ram Rachum.
 # This program is distributed under the MIT license.
 
 '''This module defines logic-related tools.'''
@@ -6,7 +6,6 @@
 import collections
 
 from python_toolbox import cute_iter_tools
-from python_toolbox import sequence_tools
 
 
 def all_equal(iterable, exhaustive=False):
@@ -25,7 +24,15 @@ def all_equal(iterable, exhaustive=False):
     # work for unhashables.
     
     if exhaustive is True:
-        pairs = sequence_tools.combinations(list(iterable), 2)
+        items = tuple(iterable)
+        if len(items) <= 1:
+            return True
+        from python_toolbox import combi
+        pairs = tuple(
+            items * comb for comb in combi.CombSpace(len(items), 2)
+        )
+        # Can't feed the items directly to `CombSpace` because they might not
+        # be hashable.
     else: # exhaustive is False
         pairs = cute_iter_tools.iterate_overlapping_subsequences(iterable)
         
@@ -70,4 +77,6 @@ def logic_max(iterable, relation=lambda a, b: (a >= b)):
             maximal_elements.append(candidate)
     
     return maximal_elements
-        
\ No newline at end of file
+                
+        
+    
\ No newline at end of file
