@@ -1,9 +1,8 @@
-# Copyright 2009-2014 Ram Rachum.
+# Copyright 2009-2015 Ram Rachum.
 # This program is distributed under the MIT license.
 
 '''Tools for monkeypatching.'''
 
-import sys
 import collections
 import inspect
 import types
@@ -71,7 +70,7 @@ def monkeypatch(monkeypatchee, name=None, override_if_exists=True):
                 #                                                             #
                 if isinstance(function, caching.CachedProperty):
                     if not isinstance(function.getter, types.FunctionType):
-                        raise NotImplemented
+                        raise NotImplementedError
                     name_ = function.getter.__name__
                 elif isinstance(function, (classmethod, staticmethod)):
                     name_ = function.__func__.__name__
