@@ -1,4 +1,4 @@
-# Copyright 2009-2014 Ram Rachum.
+# Copyright 2009-2015 Ram Rachum.
 # This program is distributed under the MIT license.
 
 '''
@@ -26,6 +26,7 @@ class OrderedDict(StdlibOrderedDict):
         link_next = link[1]
         link_prev[1] = link_next
         link_next[0] = link_prev
+        root = self.__root
         if last:
             last = self.__root[0]
             link[0] = last
@@ -36,6 +37,7 @@ class OrderedDict(StdlibOrderedDict):
             link[0] = self.__root
             link[1] = first
             root[1] = first[0] = link
+            
 
     def sort(self, key=None, reverse=False):
         '''
@@ -54,9 +56,13 @@ class OrderedDict(StdlibOrderedDict):
     def index(self, key):
         '''Get the index number of `key`.'''
         if key not in self:
-            raise KeyError
+            raise ValueError
         for i, key_ in enumerate(self):
             if key_ == key:
                 return i
         raise RuntimeError
-                
\ No newline at end of file
+    
+    @property
+    def reversed(self):
+        '''Get a version of this `OrderedDict` with key order reversed.'''
+        return type(self)(reversed(tuple(self.items())))
\ No newline at end of file
