@@ -1,19 +1,27 @@
-# Copyright 2009-2014 Ram Rachum.
+# Copyright 2009-2015 Ram Rachum.
 # This program is distributed under the MIT license.
 
 '''Defines various tools related to file-system paths.'''
 
 import sys
-import pathlib
+import os
+try:
+    import pathlib
+except:
+    from python_toolbox.third_party import pathlib
+
 import glob
 import types
 
+_is_windows = (os.name == 'nt')
+null_path = pathlib.Path(os.path.devnull)
+path_type = pathlib.WindowsPath if _is_windows else pathlib.PosixPath
 
 def list_sub_folders(path):
     '''List all the immediate sub-folders of the folder at `path`.'''
     path = pathlib.Path(path)
     assert path.is_dir()
-    return list(filter(pathlib.Path.is_dir, path.glob('*')))
+    return tuple(filter(pathlib.Path.is_dir, path.glob('*')))
 
 
 def get_path_of_package(package):
@@ -48,3 +56,4 @@ def get_root_path_of_module(module):
                               map(pathlib.Path, sys.path)))
     return result
 
+
