@@ -1,4 +1,4 @@
-# Copyright 2009-2014 Ram Rachum.
+# Copyright 2009-2015 Ram Rachum.
 # This program is distributed under the MIT license.
 
 '''Testing module for `python_toolbox.caching.CachedProperty`.'''
@@ -35,6 +35,23 @@ def test():
     
     assert a2.personality == a1.personality + 1
 
+def test_inheritance():
+    class A(object):
+        personality = CachedProperty(counting_func)
+    
+    class B(A):
+        pass
+    
+    assert isinstance(B.personality, CachedProperty)
+        
+    b1 = B()
+    assert b1.personality == b1.personality == b1.personality
+    
+    b2 = B()
+    assert b2.personality == b2.personality == b2.personality 
+    
+    assert b2.personality == b1.personality + 1
+
 def test_value():
     '''Test `CachedProperty` when giving a value instead of a getter.'''
     class B(object):
