@@ -1,4 +1,4 @@
-# Copyright 2009-2013 Ram Rachum.
+# Copyright 2009-2015 Ram Rachum.
 # This program is distributed under the MIT license.
 
 # We're importing `pickle_module` from `pickle_tools`, so we get the exact same
@@ -16,7 +16,7 @@ from python_toolbox import pickle_tools
 my_messy_object = (
     'Whatever',
     {1: 2,}, 
-    set([3, 4]), 
+    {3, 4}, 
     frozenset([3, 4]),
     ((((((((((((())))))))))))),
     u'unicode_too',
