@@ -1,4 +1,4 @@
-# Copyright 2009-2014 Ram Rachum.
+# Copyright 2009-2015 Ram Rachum.
 # This program is distributed under the MIT license.
 
 '''Defines several functions that may be useful when working with dicts.'''
@@ -45,9 +45,9 @@ def filter_items(d, condition, double=False, force_dict_type=None):
         )
 
 
-def get_list(d, iterable):
-    '''Get a list of values corresponding to an `iterable` of keys.'''
-    return [d[key] for key in iterable]
+def get_tuple(d, iterable):
+    '''Get a tuple of values corresponding to an `iterable` of keys.'''
+    return tuple(d[key] for key in iterable)
 
 
 def get_contained(d, container):
@@ -191,10 +191,10 @@ def remove_keys(d, keys_to_remove):
                 del d[key]
             
             
-        
-    
-    
-    
-    
-    
+def get_sorted_values(d, key=None):
+    '''
+    Get the values of dict `d` as a `tuple` sorted by their respective keys.
+    '''
+    kwargs = {'key': key,} if key is not None else {}
+    return get_tuple(d, sorted(d.keys(), **kwargs))
     
\ No newline at end of file
