@@ -1,18 +1,21 @@
-# Copyright 2009-2014 Ram Rachum.
+# Copyright 2009-2015 Ram Rachum.
 # This program is distributed under the MIT license.
 
 '''This module defines miscellaneous tools.'''
 
 import operator
-import pathlib
+try:
+    import pathlib
+except:
+    from python_toolbox.third_party import pathlib
+
 import re
 import math
 import types
 import functools
+import sys
 import threading
 
-from python_toolbox import cute_iter_tools
-
 
 _email_pattern = re.compile(
     r"(^[-!#$%&'*+/=?^_`{}|~0-9A-Z]+(\.[-!#$%&'*+/=?^_`{}|~0-9A-Z]+)*"
@@ -37,6 +40,7 @@ def is_subclass(candidate, base_class):
     not a type. (Python issue 10569.)
     '''
     # todo: disable ability to use nested iterables.
+    from python_toolbox import cute_iter_tools
     if cute_iter_tools.is_iterable(base_class):
         return any(is_subclass(candidate, single_base_class) for 
                    single_base_class in base_class)
@@ -68,22 +72,6 @@ def get_mro_depth_of_method(type_, method_name):
     return deepest_index
 
 
-def frange(start, finish=None, step=1.):
-    '''
-    Make a `list` containing an arithmetic progression of numbers.
-
-    This is an extension of the builtin `range`; it allows using floating point
-    numbers.
-    '''
-    if finish is None:
-        finish, start = start, 0.
-    else:
-        start = float(start)
-
-    count = int(math.ceil(finish - start)/step)
-    return (start + n*step for n in range(count))
-    
-
 def getted_vars(thing, _getattr=getattr):
     '''
     The `vars` of an object, but after we used `getattr` to get them.
@@ -187,6 +175,8 @@ def find_clear_place_on_circle(circle_points, circle_size=1):
     interval connects to the start.)
     '''
 
+    from python_toolbox import cute_iter_tools
+
     # Before starting, taking care of two edge cases:
     if not circle_points:
         # Edge case: No points at all
@@ -355,4 +345,32 @@ def decimal_number_from_string(string):
         raise Exception("%s isn't a decimal number." % string)
     if not _decimal_number_pattern.match(string):
         raise Exception("%s isn't a decimal number." % string)
-    return float(string) if '.' in string else int(string)
\ No newline at end of file
+    return float(string) if '.' in string else int(string)
+
+
+
+class AlternativeLengthMixin:
+    '''
+    Mixin for sized types that makes it easy to return non-standard lengths.
+    
+    Due to CPython limitation, Python's built-in `__len__` (and its counterpart
+    `len`) can't return really big values or floating point numbers.
+    
+    Classes which need to return such lengths can use this mixin. They'll have
+    to define a property `length` where they return their length, and if
+    someone tries to call `len` on it, then if the length happens to be a
+    number that `len` supports, it'll return that, otherwise it'll show a
+    helpful error message.
+    '''
+    def __len__(self):
+        length = self.length
+        if (length <= sys.maxsize) and isinstance(length, int):
+            return length
+        else:
+            raise OverflowError("Due to CPython limitation, you'll have to "
+                                "use `.length` rather than `len`")
+        
+    def __bool__(self):
+        from python_toolbox import sequence_tools
+        return bool(sequence_tools.get_length(self))
+        
