@@ -1,4 +1,4 @@
-# Copyright 2009-2014 Ram Rachum.
+# Copyright 2009-2015 Ram Rachum.
 # This program is distributed under the MIT license.
 
 '''
@@ -31,9 +31,13 @@ class OrderedDict(StdlibOrderedDict):
     def index(self, key):
         '''Get the index number of `key`.'''
         if key not in self:
-            raise KeyError
+            raise ValueError
         for i, key_ in enumerate(self):
             if key_ == key:
                 return i
         raise RuntimeError
-                
\ No newline at end of file
+    
+    @property
+    def reversed(self):
+        '''Get a version of this `OrderedDict` with key order reversed.'''
+        return type(self)(reversed(tuple(self.items())))
\ No newline at end of file
