@@ -1,4 +1,4 @@
-# Copyright 2009-2014 Ram Rachum.
+# Copyright 2009-2015 Ram Rachum.
 # This program is distributed under the MIT license.
 
 '''Various os-related tools.'''
@@ -6,7 +6,6 @@
 import subprocess
 import sys
 import os.path
-import pathlib
 
 
 def start_file(path):
@@ -28,7 +27,4 @@ def start_file(path):
             "Your operating system `%s` isn't supported by "
             "`start_file`." % sys.platform)
     
-    
-_is_windows = (os.name == 'nt')
-null_path = pathlib.Path(os.path.devnull)
-path_type = pathlib.WindowsPath if _is_windows else pathlib.PosixPath
\ No newline at end of file
+    
\ No newline at end of file
