@@ -1,4 +1,4 @@
-# Copyright 2009-2014 Ram Rachum.
+# Copyright 2009-2015 Ram Rachum.
 # This program is distributed under the MIT license.
 
 '''Testing module for `python_toolbox.address_tools.describe`.'''
@@ -27,9 +27,9 @@ def test_on_locally_defined_class():
     # Testing for locally defined class:
     
     
-    if python_toolbox.__version_info__ <= (0, 6, 11, 'release'):
+    if python_toolbox.__version_info__ <= (0, 7, 0, 'release'):
         raise nose.SkipTest("This test doesn't pass in `python_toolbox` "
-                            "version 0.6.11 and below, because `describe` :"
+                            "version 0.7.0 and below, because `describe` :"
                             "doesn't support nested classes yet.")
     
     result = describe(A.B)
@@ -199,8 +199,6 @@ def test_address_in_expression():
 
 def test_multiprocessing_lock():
     '''Test `describe` works for `multiprocessing.Lock()`.'''
-    if not import_tools.exists('multiprocessing'):
-        raise nose.SkipTest('`multiprocessing` not installed')
     import multiprocessing
     lock = multiprocessing.Lock()
     describe(lock)
@@ -247,9 +245,9 @@ def test_bad_module_name():
 
 def test_function_in_something():
     '''Test `describe` doesn't fail when describing `{1: sum}`.'''
-    if python_toolbox.__version_info__ <= (0, 6, 11, 'release'):
+    if python_toolbox.__version_info__ <= (0, 7, 0, 'release'):
         raise nose.SkipTest("This test doesn't pass in `python_toolbox`"
-                            "version 0.6.11 and below.")
+                            "version 0.7.0 and below.")
     assert describe({1: sum}) == '{1: sum}'
     assert describe((sum, sum, list, chr)) == '(sum, sum, list, chr)'
     
